pub enum HttpCertificationError {
MalformedUrl(String),
Utf8ConversionError(FromUtf8Error),
WildcardPathNotValidForRequestPath {
wildcard_path: String,
request_path: String,
},
CertificateExpressionHeaderMismatch {
expected: String,
actual: String,
},
CertificateExpressionHeaderMissing {
expected: String,
},
MultipleCertificateExpressionHeaders {
expected: String,
},
InvalidHttpStatusCode {
status_code: u16,
},
}Expand description
HTTP certification error type.
Variants
MalformedUrl(String)
The URL was malformed and could not be parsed correctly.
Utf8ConversionError(FromUtf8Error)
Error converting UTF-8 string.
WildcardPathNotValidForRequestPath
Error converting bytes to string.
Fields
CertificateExpressionHeaderMismatch
The IC-CertificateExpression header in a response did not match the Cel expression used to certify the HttpResponse.
Fields
expected: StringThe expected value of the IC-CertificateExpression header. This is the Cel expression used to certify the HttpResponse.
CertificateExpressionHeaderMissing
The IC-CertificateExpression header was missing from the HttpResponse.
Fields
expected: StringThe expected value of the IC-CertificateExpression header. This is the Cel expression used to certify the HttpResponse.
MultipleCertificateExpressionHeaders
The IC-CertificateExpression header in a response contained multiple values.
Fields
expected: StringThe expected value of the IC-CertificateExpression header. This is the Cel expression used to certify the HttpResponse.
InvalidHttpStatusCode
Error converting a number into an HTTP status code.