Utilities for calculating Representation Independent Hashes of HttpRequest and HttpResponse objects.
Structs
- Response
Headers - Representation of response headers filtered by filter_response_headers.
Constants
- CERTIFICATE_
EXPRESSION_ HEADER_ NAME - The name of the IC-CertificateExpression header.
- CERTIFICATE_
HEADER_ NAME - The name of the IC-Certificate header.
- RESPONSE_
STATUS_ PSEUDO_ HEADER_ NAME - The pseudo-header name used for encoding the response status code in the Representation Independent Hash.
Functions
- filter_
response_ headers - Filters the headers of an HttpResponse according to a CEL expression defined by DefaultResponseCertification.
- request_
hash - Calculates the Representation Independent Hash of an HttpRequest according to a CEL expression defined by DefaultRequestCertification.
- response_
hash - Calculates the Representation Independent Hash of an HttpResponse according to a CEL expression defined by DefaultResponseCertification.
- response_
hash_ from_ headers - Computes the v2 response hash from pre-built header pairs, a status code, and a body hash.
- response_
headers_ hash - Calculates the Representation Independent Hash of ResponseHeaders that have been filtered with filter_response_headers.
Type Aliases
- Hash
- Sha256 Digest: 32 bytes